pytafseer package
=================

Submodules
----------

pytafseer.settings module
-------------------------

.. automodule:: pytafseer.settings
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pytafseer
    :members:
    :undoc-members:
    :show-inheritance:
